@@ -27,7 +27,7 @@ if (!&Forks::Super::Util::IS_WIN32ish) {
 #   http://msdn.microsoft.com/en-us/library/ms684847(VS.85).aspx
 
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 our ($_THREAD_API, $_THREAD_API_INITIALIZED, %SYSTEM_INFO);
 
 ##################################################################
@@ -80,7 +80,7 @@ eval {
 
     1;
 
-} or carp $@; # or carp 'Win32::API module is highly highly recommended ';
+} or carp 'Win32::API module is highly recommended ';
 
 
 our %_WIN32_API_SPECS = (
